@@ -28,6 +28,9 @@
 
 #include <QTextStream>
 
+#include "keepassxmlstreamreader.h"
+#include "keepassxmlstreamwriter.h"
+
 EntryStorage::EntryStorage(QObject *parent) :
     QObject(parent)
 {
@@ -36,7 +39,7 @@ EntryStorage::EntryStorage(QObject *parent) :
 #endif
 
     qDebug("Initializing QCA...");
-    initializer = new QCA::Initializer();
+    initializer = new QCA::Initializer(QCA::Practical, 256);
     qDebug("QCA initialized.");
 
     QCA::scanForPlugins();
@@ -46,6 +49,9 @@ EntryStorage::EntryStorage(QObject *parent) :
     capabilities = QCA::supportedFeatures();
     qDebug("QCA supports: %s", capabilities.join(",").toUtf8().constData());
 
+    model = new EntryListModel();
+    connect(model, SIGNAL(changed()), this, SLOT(storeModel()));
+
     key = NULL;
 }
 
@@ -61,13 +67,17 @@ EntryStorage::~EntryStorage(){
     if(initializer != NULL){
         delete initializer;
     }
+    if(model != NULL) {
+        disconnect(model, SIGNAL(changed()), this, SLOT(storeModel()));
+        delete model;
+    }
 }
 
 bool EntryStorage::equalsStoredPassword(QString password){
     return (key != NULL && *key == QCA::SymmetricKey(QByteArray(password.toUtf8().constData())));
 }
 
-void EntryStorage::loadAndDecryptData(QString password, EntryListModel *model){
+void EntryStorage::loadAndDecryptData(QString password){
     QByteArray encryptedData;
 
     setPassword(password);
@@ -195,7 +205,7 @@ void EntryStorage::setPassword(QString password){
 }
 
 
-void EntryStorage::storeModel(EntryListModel *model){
+void EntryStorage::storeModel(){
     qDebug("Storing model...");
 
     qDebug("Get data from model.");
@@ -243,3 +253,13 @@ void EntryStorage::storeModel(EntryListModel *model){
     qDebug("File successfully written.");
 #endif
 }
+
+void EntryStorage::exportKeePassXml(){
+    KeePassXmlStreamWriter writer;
+    writer.exportList(model->getEntryList());
+}
+
+void EntryStorage::importKeePassXml(){
+    KeePassXmlStreamReader reader;
+    model->appendEntries(reader.openFileForImport());
+}
