@@ -45,6 +45,10 @@ public:
     ~EntryStorage();
 
     Q_INVOKABLE bool equalsStoredPassword(QString password);
+    Q_INVOKABLE EntryListModel* getModel() { return model; }
+
+    Q_INVOKABLE void exportKeePassXml();
+    Q_INVOKABLE void importKeePassXml();
 
 signals:
     void decryptionFailed();
@@ -57,10 +61,10 @@ signals:
     void storageOpenSuccessNewPassword();
 
 public slots:
-    void loadAndDecryptData(QString password, EntryListModel *model);
+    void loadAndDecryptData(QString password);
     void openStorage();
     void setPassword(QString password);
-    void storeModel(EntryListModel *model);
+    void storeModel();
 
 private:
 #ifdef MEEGO_EDITION_HARMATTAN
@@ -69,6 +73,8 @@ private:
 
     QCA::Initializer *initializer;
     QCA::SymmetricKey *key;
+
+    EntryListModel *model;
 };
 
 #endif // ENTRYSTORAGE_H
