@@ -34,6 +34,7 @@
 //#include "mcomboboxqmladapter.h"
 //#include "mtexteditqmladapter.h"
 #include "qcomboboxqmladapter.h"
+#include "qmlclipboardadapter.h"
 //#include "qlineeditqmladapter.h"
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
@@ -61,6 +62,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 //    qmlRegisterType<MComboBoxQmlAdapter>("meepasswords", 1, 0, "MComboBox");
 //    qmlRegisterType<MTextEditQmlAdapter>("meepasswords", 1, 0, "MTextEdit");
     qmlRegisterType<QComboBoxQmlAdapter>("meepasswords", 1, 0, "QComboBox");
+    qmlRegisterType<QmlClipboardAdapter>("meepasswords", 1, 0, "QClipboard");
 //    qmlRegisterType<QLineEditQmlAdapter>("meepasswords", 1, 0, "QLineEdit");
 
     /*
