@@ -66,17 +66,7 @@ QComboBoxQmlAdapter::~QComboBoxQmlAdapter(){
     delete m_comboBox;
 }
 
-void QComboBoxQmlAdapter::setItems(EntryListModel *model){
-    QStringList items;
-
-    for(int i = 0; i < model->rowCount(); i++){
-        QString category = model->at(i)->category();
-
-        if(! items.contains(category)){
-            items.append(category);
-        }
-    }
-
+void QComboBoxQmlAdapter::setItems(const QStringList &items){
     QString temp = m_comboBox->currentText();
     m_comboBox->clear();
     m_comboBox->addItems(items);
